poloniex
========

*Poloniex python API client for humans*

Description
-----------

Alpha version of a `Poloniex API`_ client for humans

Installation
------------

The package has been uploaded to `PyPI`_, so you can install it with pip:

    pip install poloniex


.. _PyPI: https://pypi.python.org/pypi/poloniex
.. _Poloniex API: https://poloniex.com/support/api/
